==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/vo/MechanicalleasedetotaldetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 月度机械设备租赁结算汇总子表
 * 
 * @author generator
 * 
 */
public class MechanicalleasedetotaldetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.String sort; // 序号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long supplier; // 租赁商
    private java.lang.String supplierName; // 租赁商名称
    private java.lang.String classifyCode; // 设备分类编码
    private java.lang.String classifyName; // 设备分类名称
    private java.math.BigDecimal exTaxMonthSettlement; // 本月结算金额(除税)
    private java.math.BigDecimal inTaxMonthSettlement; // 本月结算金额(含税)
    private java.math.BigDecimal exTaxCumulativeSettlement; // 累计结算(除税)
    private java.math.BigDecimal inTaxCumulativeSettlement; // 累计结算(含税)
    private java.math.BigDecimal exTaxCumulativeDue; // 至本月累计应付款金额
    private java.math.BigDecimal inTaxCumulativePaid; // 至本月累计付款金额
    private java.math.BigDecimal contractPaidRatio; // 合同付款比例
    private java.lang.String remarks; // 备注
    private java.lang.String linker; // 联系人
    private java.lang.String linkerPhone; // 联系方式
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 租赁商
     */
    public java.lang.Long getSupplier() {
        return supplier;
    }

    /**
     * 租赁商
     */
    public void setSupplier(java.lang.Long supplier) {
        this.supplier = supplier;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 租赁商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 设备分类编码
     */
    public java.lang.String getClassifyCode() {
        return classifyCode;
    }

    /**
     * 设备分类编码
     */
    public void setClassifyCode(java.lang.String classifyCode) {
        this.classifyCode = classifyCode;
    }
    /**
     * 设备分类名称
     */
    public java.lang.String getClassifyName() {
        return classifyName;
    }

    /**
     * 设备分类名称
     */
    public void setClassifyName(java.lang.String classifyName) {
        this.classifyName = classifyName;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getExTaxMonthSettlement() {
        return exTaxMonthSettlement;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setExTaxMonthSettlement(java.math.BigDecimal exTaxMonthSettlement) {
        this.exTaxMonthSettlement = exTaxMonthSettlement;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getInTaxMonthSettlement() {
        return inTaxMonthSettlement;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setInTaxMonthSettlement(java.math.BigDecimal inTaxMonthSettlement) {
        this.inTaxMonthSettlement = inTaxMonthSettlement;
    }
    /**
     * 累计结算(除税)
     */
    public java.math.BigDecimal getExTaxCumulativeSettlement() {
        return exTaxCumulativeSettlement;
    }

    /**
     * 累计结算(除税)
     */
    public void setExTaxCumulativeSettlement(java.math.BigDecimal exTaxCumulativeSettlement) {
        this.exTaxCumulativeSettlement = exTaxCumulativeSettlement;
    }
    /**
     * 累计结算(含税)
     */
    public java.math.BigDecimal getInTaxCumulativeSettlement() {
        return inTaxCumulativeSettlement;
    }

    /**
     * 累计结算(含税)
     */
    public void setInTaxCumulativeSettlement(java.math.BigDecimal inTaxCumulativeSettlement) {
        this.inTaxCumulativeSettlement = inTaxCumulativeSettlement;
    }
    /**
     * 至本月累计应付款金额
     */
    public java.math.BigDecimal getExTaxCumulativeDue() {
        return exTaxCumulativeDue;
    }

    /**
     * 至本月累计应付款金额
     */
    public void setExTaxCumulativeDue(java.math.BigDecimal exTaxCumulativeDue) {
        this.exTaxCumulativeDue = exTaxCumulativeDue;
    }
    /**
     * 至本月累计付款金额
     */
    public java.math.BigDecimal getInTaxCumulativePaid() {
        return inTaxCumulativePaid;
    }

    /**
     * 至本月累计付款金额
     */
    public void setInTaxCumulativePaid(java.math.BigDecimal inTaxCumulativePaid) {
        this.inTaxCumulativePaid = inTaxCumulativePaid;
    }
    /**
     * 合同付款比例
     */
    public java.math.BigDecimal getContractPaidRatio() {
        return contractPaidRatio;
    }

    /**
     * 合同付款比例
     */
    public void setContractPaidRatio(java.math.BigDecimal contractPaidRatio) {
        this.contractPaidRatio = contractPaidRatio;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 联系人
     */
    public java.lang.String getLinker() {
        return linker;
    }

    /**
     * 联系人
     */
    public void setLinker(java.lang.String linker) {
        this.linker = linker;
    }
    /**
     * 联系方式
     */
    public java.lang.String getLinkerPhone() {
        return linkerPhone;
    }

    /**
     * 联系方式
     */
    public void setLinkerPhone(java.lang.String linkerPhone) {
        this.linkerPhone = linkerPhone;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/vo/MechanicalleasedetotaldetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 月度机械设备租赁结算汇总子表
 * 
 * @author generator
 * 
 */
public class MechanicalleasedetotaldetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.String sort; // 序号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long contract; // 合同
    private java.lang.String contractName; // 合同名称
    private java.lang.Long supplier; // 租赁商
    private java.lang.String supplierName; // 租赁商名称
    private java.lang.String classifyCode; // 设备分类编码
    private java.lang.String classifyName; // 设备分类名称
    private java.math.BigDecimal exTaxMonthSettlement; // 本月结算金额(除税)
    private java.math.BigDecimal inTaxMonthSettlement; // 本月结算金额(含税)
    private java.math.BigDecimal exTaxCumulativeSettlement; // 累计结算(除税)
    private java.math.BigDecimal inTaxCumulativeSettlement; // 累计结算(含税)
    private java.math.BigDecimal exTaxCumulativeDue; // 至本月累计应付款金额
    private java.math.BigDecimal inTaxCumulativePaid; // 至本月累计付款金额
    private java.math.BigDecimal contractPaidRatio; // 合同付款比例
    private java.lang.String remarks; // 备注
    private java.lang.String linker; // 联系人
    private java.lang.String linkerPhone; // 联系方式

    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 租赁商
     */
    public java.lang.Long getSupplier() {
        return supplier;
    }

    /**
     * 租赁商
     */
    public void setSupplier(java.lang.Long supplier) {
        this.supplier = supplier;
    }
    /**
     * 租赁商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 租赁商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 设备分类编码
     */
    public java.lang.String getClassifyCode() {
        return classifyCode;
    }

    /**
     * 设备分类编码
     */
    public void setClassifyCode(java.lang.String classifyCode) {
        this.classifyCode = classifyCode;
    }
    /**
     * 设备分类名称
     */
    public java.lang.String getClassifyName() {
        return classifyName;
    }

    /**
     * 设备分类名称
     */
    public void setClassifyName(java.lang.String classifyName) {
        this.classifyName = classifyName;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getExTaxMonthSettlement() {
        return exTaxMonthSettlement;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setExTaxMonthSettlement(java.math.BigDecimal exTaxMonthSettlement) {
        this.exTaxMonthSettlement = exTaxMonthSettlement;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getInTaxMonthSettlement() {
        return inTaxMonthSettlement;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setInTaxMonthSettlement(java.math.BigDecimal inTaxMonthSettlement) {
        this.inTaxMonthSettlement = inTaxMonthSettlement;
    }
    /**
     * 累计结算(除税)
     */
    public java.math.BigDecimal getExTaxCumulativeSettlement() {
        return exTaxCumulativeSettlement;
    }

    /**
     * 累计结算(除税)
     */
    public void setExTaxCumulativeSettlement(java.math.BigDecimal exTaxCumulativeSettlement) {
        this.exTaxCumulativeSettlement = exTaxCumulativeSettlement;
    }
    /**
     * 累计结算(含税)
     */
    public java.math.BigDecimal getInTaxCumulativeSettlement() {
        return inTaxCumulativeSettlement;
    }

    /**
     * 累计结算(含税)
     */
    public void setInTaxCumulativeSettlement(java.math.BigDecimal inTaxCumulativeSettlement) {
        this.inTaxCumulativeSettlement = inTaxCumulativeSettlement;
    }
    /**
     * 至本月累计应付款金额
     */
    public java.math.BigDecimal getExTaxCumulativeDue() {
        return exTaxCumulativeDue;
    }

    /**
     * 至本月累计应付款金额
     */
    public void setExTaxCumulativeDue(java.math.BigDecimal exTaxCumulativeDue) {
        this.exTaxCumulativeDue = exTaxCumulativeDue;
    }
    /**
     * 至本月累计付款金额
     */
    public java.math.BigDecimal getInTaxCumulativePaid() {
        return inTaxCumulativePaid;
    }

    /**
     * 至本月累计付款金额
     */
    public void setInTaxCumulativePaid(java.math.BigDecimal inTaxCumulativePaid) {
        this.inTaxCumulativePaid = inTaxCumulativePaid;
    }
    /**
     * 合同付款比例
     */
    public java.math.BigDecimal getContractPaidRatio() {
        return contractPaidRatio;
    }

    /**
     * 合同付款比例
     */
    public void setContractPaidRatio(java.math.BigDecimal contractPaidRatio) {
        this.contractPaidRatio = contractPaidRatio;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 联系人
     */
    public java.lang.String getLinker() {
        return linker;
    }

    /**
     * 联系人
     */
    public void setLinker(java.lang.String linker) {
        this.linker = linker;
    }
    /**
     * 联系方式
     */
    public java.lang.String getLinkerPhone() {
        return linkerPhone;
    }

    /**
     * 联系方式
     */
    public void setLinkerPhone(java.lang.String linkerPhone) {
        this.linkerPhone = linkerPhone;
    }
    
}
